patch 7.4.1969
Problem:    When the netbeans channel is closed consuming the buffer may cause
            a crash.
Solution:   Check for nb_channel not to be NULL. (Xavier de Gaye)
diff --git a/src/version.c b/src/version.c
index 2a3ded7..8e9da45 100644
--- a/src/version.c
+++ b/src/version.c
@@ -754,6 +754,8 @@
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    1969,
+/**/
     1968,
 /**/
     1967,
diff --git a/src/netbeans.c b/src/netbeans.c
index 46d725b..f674a78 100644
--- a/src/netbeans.c
+++ b/src/netbeans.c
@@ -422,13 +422,14 @@
 	    buffer = node->rq_buffer;
 	}
 
 	/* now, parse and execute the commands */
 	nb_parse_cmd(buffer);
 
 	if (own_node)
 	    /* buffer finished, dispose of it */
 	    vim_free(buffer);
-	else
+	else if (nb_channel != NULL)
 	    /* more follows, move it to the start */
 	    channel_consume(nb_channel, PART_SOCK, (int)(p - buffer));
     }
@@ -422,13 +422,14 @@
 	}
 
-	/* now, parse and execute the commands */
+	/* Now, parse and execute the commands.  This may set nb_channel to
+	 * NULL if the channel is closed. */
 	nb_parse_cmd(buffer);
 